# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.dashboard.notebook_utils` instead.
"""

import warnings

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.dashboard.notebook_utils import is_notebook
from trulens.dashboard.notebook_utils import setup_widget_stdout_stderr



# ruff: noqa: E402, F403, F401
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.core.database.sqlalchemy` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.core.database.sqlalchemy import MIGRATION_UNKNOWN_STR
from trulens.core.database.sqlalchemy import UNICODE_CHECK
from trulens.core.database.sqlalchemy import UNICODE_CLOCK
from trulens.core.database.sqlalchemy import UNICODE_HOURGLASS
from trulens.core.database.sqlalchemy import UNICODE_STOP
from trulens.core.database.sqlalchemy import AppsExtractor
from trulens.core.database.sqlalchemy import SnowflakeImpl
from trulens.core.database.sqlalchemy import SQLAlchemyDB
from trulens.core.database.sqlalchemy import flatten
from trulens.core.database.sqlalchemy import no_perf



# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use `trulens.core.utils.json`
    or `trulens.core.utils.pyschema` instead.
"""

import warnings

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.core.utils.json import ALL_SPECIAL_KEYS
from trulens.core.utils.json import CIRCLE
from trulens.core.utils.json import CLASS_INFO
from trulens.core.utils.json import JSON_BASES
from trulens.core.utils.json import encode_httpx_url
from trulens.core.utils.json import encode_openai_timeout
from trulens.core.utils.json import json_default
from trulens.core.utils.json import json_str_of_obj
from trulens.core.utils.json import jsonify
from trulens.core.utils.json import jsonify_for_ui
from trulens.core.utils.json import obj_id_of_obj
from trulens.core.utils.pyschema import ERROR
from trulens.core.utils.pyschema import NOSERIO



# ruff: noqa: E402, F403, F401
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.core.database.utils` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.core.database.utils import check_db_revision
from trulens.core.database.utils import coerce_ts
from trulens.core.database.utils import copy_database
from trulens.core.database.utils import is_legacy_sqlite
from trulens.core.database.utils import is_memory_sqlite



# ruff: noqa: E402
"""
!!! warning
    This module is deprecated and will be removed. Use `trulens.feedback` and
    `trulens.providers.*` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

from trulens_eval._utils import optional as optional_utils

deprecation_utils.packages_dep_warn()

from trulens.core.feedback.endpoint import Endpoint
from trulens.core.utils import imports as imports_utils
from trulens.feedback.dummy.endpoint import DummyEndpoint

with imports_utils.OptionalImports(
    messages=optional_utils.REQUIREMENT_PROVIDER_LITELLM
):
    from trulens.providers.litellm.endpoint import LiteLLMEndpoint

with imports_utils.OptionalImports(
    messages=optional_utils.REQUIREMENT_PROVIDER_BEDROCK
):
    from trulens.providers.bedrock.endpoint import BedrockEndpoint

with imports_utils.OptionalImports(
    messages=optional_utils.REQUIREMENT_PROVIDER_OPENAI
):
    from trulens.providers.openai.endpoint import OpenAIClient
    from trulens.providers.openai.endpoint import OpenAIEndpoint

with imports_utils.OptionalImports(
    messages=optional_utils.REQUIREMENT_PROVIDER_CORTEX
):
    from trulens.providers.cortex.endpoint import CortexEndpoint

with imports_utils.OptionalImports(
    messages=optional_utils.REQUIREMENT_PROVIDER_LANGCHAIN
):
    from trulens.providers.langchain.endpoint import LangchainEndpoint

with imports_utils.OptionalImports(
    messages=optional_utils.REQUIREMENT_PROVIDER_HUGGINGFACE
):
    from trulens.providers.huggingface.endpoint import HuggingfaceEndpoint

__all__ = [
    "Endpoint",
    "DummyEndpoint",
    "HuggingfaceEndpoint",
    "OpenAIEndpoint",
    "LiteLLMEndpoint",
    "BedrockEndpoint",
    "OpenAIClient",
    "LangchainEndpoint",
    "CortexEndpoint",
]

# Replace all classes we expose to ones which issue a deprecation warning upon
# initialization.
deprecation_utils.moved(
    globals(),
    names=__all__,
    old="trulens_eval.feedback.provider.endpoint",
    new="trulens.providers",
)



# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use `trulens.core.app.base`,
    `trulens.apps.langchain.langchain`, or
    `trulens.apps.llamaindex.llama` instead.

"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.apps.langchain.langchain import LangChainComponent
from trulens.apps.llamaindex.llama import LlamaIndexComponent
from trulens.core.app import ATTRIBUTE_ERROR_MESSAGE
from trulens.core.app import CLASS_INFO
from trulens.core.app import JSON_BASES
from trulens.core.app import LLM
from trulens.core.app import Agent
from trulens.core.app import App
from trulens.core.app import ComponentView
from trulens.core.app import CustomComponent
from trulens.core.app import Memory
from trulens.core.app import Other
from trulens.core.app import Prompt
from trulens.core.app import RecordingContext
from trulens.core.app import Tool
from trulens.core.app import TrulensComponent
from trulens.core.app import instrumented_component_views



# ruff: noqa: E401, E402, F401, F403
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.providers.huggingface.provider` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.providers.huggingface.provider import (
    HUGS_CONTEXT_RELEVANCE_API_URL,
)
from trulens.providers.huggingface.provider import HUGS_DOCNLI_API_URL
from trulens.providers.huggingface.provider import HUGS_DOCNLI_MODEL_PATH
from trulens.providers.huggingface.provider import HUGS_HALLUCINATION_API_URL
from trulens.providers.huggingface.provider import HUGS_LANGUAGE_API_URL
from trulens.providers.huggingface.provider import HUGS_NLI_API_URL
from trulens.providers.huggingface.provider import HUGS_PII_DETECTION_API_URL
from trulens.providers.huggingface.provider import HUGS_SENTIMENT_API_URL
from trulens.providers.huggingface.provider import HUGS_TOXIC_API_URL
from trulens.providers.huggingface.provider import Dummy
from trulens.providers.huggingface.provider import Huggingface
from trulens.providers.huggingface.provider import HuggingfaceBase
from trulens.providers.huggingface.provider import HuggingfaceLocal



# ruff: noqa: E401, E402, F401, F403
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.core.utils.keys` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.core.utils.keys import REDACTED_VALUE
from trulens.core.utils.keys import TEMPLATE_VALUES
from trulens.core.utils.keys import UNICODE_CHECK
from trulens.core.utils.keys import UNICODE_STOP
from trulens.core.utils.keys import ApiKeyError
from trulens.core.utils.keys import check_keys
from trulens.core.utils.keys import check_or_set_keys
from trulens.core.utils.keys import cohere_agent
from trulens.core.utils.keys import get_config
from trulens.core.utils.keys import get_config_file
from trulens.core.utils.keys import get_huggingface_headers
from trulens.core.utils.keys import redact_value
from trulens.core.utils.keys import should_redact_key
from trulens.core.utils.keys import should_redact_value
from trulens.core.utils.keys import values_to_redact



# ruff: noqa: E401, E402, F401, F403
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.providers.bedrock.endpoint` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.providers.bedrock.endpoint import INSTRUMENT
from trulens.providers.bedrock.endpoint import BedrockCallback
from trulens.providers.bedrock.endpoint import BedrockEndpoint



# ruff: noqa: E401, E402, F401, F403
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.core.instruments` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.core.instruments import AddInstruments
from trulens.core.instruments import Instrument
from trulens.core.instruments import WithInstrumentCallbacks
from trulens.core.instruments import class_filter_disjunction
from trulens.core.instruments import class_filter_matches
from trulens.core.instruments import instrument



# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use `trulens.core.utils.text`
    instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.core.utils.text import UNICODE_CHECK
from trulens.core.utils.text import UNICODE_CLOCK
from trulens.core.utils.text import UNICODE_HOURGLASS
from trulens.core.utils.text import UNICODE_LOCK
from trulens.core.utils.text import UNICODE_SQUID
from trulens.core.utils.text import UNICODE_STOP
from trulens.core.utils.text import UNICODE_YIELD
from trulens.core.utils.text import make_retab
from trulens.core.utils.text import retab



# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.apps.llamaindex.llama` instead.
"""

import warnings

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.apps.llamaindex.llama import COMPONENT_VIEWS
from trulens.apps.llamaindex.llama import LLM
from trulens.apps.llamaindex.llama import Agent
from trulens.apps.llamaindex.llama import Other
from trulens.apps.llamaindex.llama import Prompt
from trulens.apps.llamaindex.llama import Tool
from trulens.apps.llamaindex.llama import component_of_json
from trulens.apps.llamaindex.llama import constructor_of_class



# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use `trulens.benchmark.generate_test_set`
    instead.
"""

from trulens.core.utils import deprecation as deprecation_utils
from trulens.core.utils import imports as import_utils

deprecation_utils.packages_dep_warn()

with import_utils.OptionalImports(
    messages=import_utils.format_import_errors(
        "trulens-benchmark",
        purpose="generating test sets",
    )
) as opt:
    from trulens.benchmark.generate import generate_test_set as mod_generate


opt.assert_installed(mod_generate)

GenerateTestSet = mod_generate.GenerateTestSet



# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.core.utils.python` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.core.utils.python import STACK
from trulens.core.utils.python import EmptyType
from trulens.core.utils.python import OpaqueWrapper
from trulens.core.utils.python import SingletonInfo
from trulens.core.utils.python import SingletonPerName
from trulens.core.utils.python import callable_name
from trulens.core.utils.python import caller_frame
from trulens.core.utils.python import caller_frameinfo
from trulens.core.utils.python import class_name
from trulens.core.utils.python import code_line
from trulens.core.utils.python import for_all_methods
from trulens.core.utils.python import get_all_local_in_call_stack
from trulens.core.utils.python import get_first_local_in_call_stack
from trulens.core.utils.python import get_task_stack
from trulens.core.utils.python import id_str
from trulens.core.utils.python import is_really_coroutinefunction
from trulens.core.utils.python import locals_except
from trulens.core.utils.python import merge_stacks
from trulens.core.utils.python import module_name
from trulens.core.utils.python import run_before
from trulens.core.utils.python import safe_hasattr
from trulens.core.utils.python import safe_issubclass
from trulens.core.utils.python import safe_signature
from trulens.core.utils.python import stack_with_tasks
from trulens.core.utils.python import task_factory_with_stack
from trulens.core.utils.python import tru_new_event_loop
from trulens.core.utils.python import wrap_awaitable
from trulens.core.utils.python import wrap_generator



# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use `trulens.dashboard.pages.Leaderboard` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.dashboard.Leaderboard import MIGRATION_UNKNOWN_STR
from trulens.dashboard.Leaderboard import leaderboard



# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use `trulens.dashboard.appui`
    instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.dashboard.appui import JSON_BASES
from trulens.dashboard.appui import VALUE_MAX_CHARS
from trulens.dashboard.appui import AppUI
from trulens.dashboard.appui import RecordWidget
from trulens.dashboard.appui import Selector
from trulens.dashboard.appui import SelectorValue
from trulens.dashboard.appui import debug_style



# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.feedback.generated` instead.
"""

import warnings

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.feedback.generated import ParseError
from trulens.feedback.generated import re_0_10_rating
from trulens.feedback.generated import validate_rating



"""Optional import messages for the backwards compat trulens_eval package."""

from trulens.core.utils.imports import format_import_errors

# Optional sub-packages:
REQUIREMENT_FEEDBACK = format_import_errors(
    "trulens-feedback", purpose="evaluating feedback functions"
)

# Other optionals:
REQUIREMENT_GROUNDEDNESS = format_import_errors(
    "nltk", purpose="using some groundedness feedback functions"
)

REQUIREMENT_PINECONE = format_import_errors(
    # package name is "pinecone-client" but module is "pinecone"
    ["pinecone-client", "langchain_community"],
    purpose="running TruBot",
)

REQUIREMENT_SKLEARN = format_import_errors(
    "scikit-learn", purpose="using embedding vector distances"
)
REQUIREMENT_BERT_SCORE = format_import_errors(
    "bert-score", purpose="measuring BERT Score"
)
REQUIREMENT_EVALUATE = format_import_errors(
    "evaluate", purpose="using certain metrics"
)
REQUIREMENT_NOTEBOOK = format_import_errors(
    ["ipython", "ipywidgets"], purpose="using TruLens-Eval in a notebook"
)
REQUIREMENT_OPENAI = format_import_errors(
    ["openai", "langchain_community"], purpose="using OpenAI models"
)

# Optional provider types:
REQUIREMENT_PROVIDER_BEDROCK = format_import_errors(
    "trulens-providers-bedrock", purpose="evaluating feedback using Bedrock"
)
REQUIREMENT_PROVIDER_CORTEX = format_import_errors(
    "trulens-providers-cortex", purpose="evaluating feedback using Cortex"
)
REQUIREMENT_PROVIDER_HUGGINGFACE = format_import_errors(
    "trulens-providers-huggingface",
    purpose="evaluating feedback using Huggingface",
)
REQUIREMENT_PROVIDER_LANGCHAIN = format_import_errors(
    "trulens-providers-langchain", purpose="evaluating feedback using LangChain"
)
REQUIREMENT_PROVIDER_LITELLM = format_import_errors(
    "trulens-providers-litellm", purpose="evaluating feedback using LiteLLM"
)
REQUIREMENT_PROVIDER_OPENAI = format_import_errors(
    "trulens-providers-openai", purpose="evaluating feedback using OpenAI"
)



# ruff: noqa: E402, F401
"""
!!! warning
    This module is deprecated and will be removed. Use `trulens.dashboard.run`
    instead.
"""

import warnings

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()


def main():
    warnings.warn(
        "This main method is deprecated. Use `trulens.dashboard.run.run_dashboard` instead.",
        DeprecationWarning,
    )
    from trulens.dashboard.run import run_dashboard

    run_dashboard()



# ruff: noqa: E402, F403, F401
"""
!!! warning
    This module is deprecated and will be removed. Use
    `trulens.feedback.feedback` or `trulens.core.feedback.feedback` instead.
"""

from trulens.core.utils import deprecation as deprecation_utils

deprecation_utils.packages_dep_warn()

from trulens.core.feedback.feedback import InvalidSelector
from trulens.core.feedback.feedback import SkipEval
from trulens.feedback.feedback import Feedback
from trulens.feedback.feedback import rag_triad



# ruff: noqa: E402
"""
!!! warning
    This module is deprecated and will be removed. Use `trulens.core`,
    `trulens.feedback`, `trulens.dashboard` instead.
"""

from trulens.core._utils import optional as optional_utils
from trulens.core.utils import deprecation as deprecation_utils
from trulens.core.utils import imports as imports_utils

from trulens_eval._utils import optional as eval_optional_utils

deprecation_utils.packages_dep_warn()

__version_info__ = (1, 0, 0, "a")
__version__ = ".".join(map(str, __version_info__))

from trulens.apps.basic import TruBasicApp
from trulens.apps.custom import TruCustomApp
from trulens.apps.virtual import TruVirtual
from trulens.core.feedback.feedback import Feedback
from trulens.core.feedback.provider import Provider
from trulens.core.schema import Select
from trulens.core.schema.feedback import FeedbackMode
from trulens.core.session import TruSession as Tru
from trulens.core.utils.threading import TP

with imports_utils.OptionalImports(
    messages=eval_optional_utils.REQUIREMENT_PROVIDER_LITELLM
):
    from trulens.providers.litellm.provider import LiteLLM

with imports_utils.OptionalImports(
    messages=eval_optional_utils.REQUIREMENT_PROVIDER_BEDROCK
):
    from trulens.providers.bedrock.provider import Bedrock

with imports_utils.OptionalImports(
    messages=eval_optional_utils.REQUIREMENT_PROVIDER_OPENAI
):
    from trulens.providers.openai.provider import AzureOpenAI
    from trulens.providers.openai.provider import OpenAI

with imports_utils.OptionalImports(
    messages=eval_optional_utils.REQUIREMENT_PROVIDER_CORTEX
):
    from trulens.providers.cortex.provider import Cortex

with imports_utils.OptionalImports(
    messages=eval_optional_utils.REQUIREMENT_PROVIDER_HUGGINGFACE
):
    from trulens.providers.huggingface.provider import Huggingface
    from trulens.providers.huggingface.provider import HuggingfaceLocal

with imports_utils.OptionalImports(
    messages=eval_optional_utils.REQUIREMENT_PROVIDER_LANGCHAIN
):
    from trulens.providers.langchain.provider import Langchain

with imports_utils.OptionalImports(
    messages=optional_utils.REQUIREMENT_APPS_LANGCHAIN
):
    from trulens.apps.langchain.tru_chain import TruChain

with imports_utils.OptionalImports(
    messages=optional_utils.REQUIREMENT_APPS_LLAMA
):
    from trulens.apps.llamaindex.tru_llama import TruLlama

with imports_utils.OptionalImports(
    messages=optional_utils.REQUIREMENT_APPS_NEMO
):
    from trulens.apps.nemo.tru_rails import TruRails

__all__ = [
    # main interface
    "Tru",
    # app types
    "TruBasicApp",
    "TruCustomApp",
    "TruChain",
    "TruLlama",
    "TruVirtual",
    "TruRails",
    # app setup
    "FeedbackMode",
    # feedback setup
    "Feedback",
    "Select",
    # feedback providers
    "Provider",
    "AzureOpenAI",
    "OpenAI",
    "Langchain",
    "LiteLLM",
    "Bedrock",
    "Huggingface",
    "HuggingfaceLocal",
    "Cortex",
    # misc utility
    "TP",
]

# Replace all classes we expose to ones which issue a deprecation warning upon
# initialization.
deprecation_utils.moved(globals(), names=__all__)
